@@ -44,6 +44,20 @@ class MissingTest:
     """
 
 
+class BrokenSymlink:
+    """ Dummy object to represent reference pointing to a BrokenSymlink path """
+
+
+class AccessDeniedPath:
+    """ Dummy object to represent reference pointing to a inaccessible path """
+
+
+class NotATest:
+    """
+    Class representing something that is not a test
+    """
+
+
 class LoaderError(Exception):
     """ Loader exception """
 
@@ -62,11 +76,12 @@ class LoaderUnhandledReferenceError(LoaderError):
         self.plugins = [_.name for _ in plugins]
 
     def __str__(self):
-        return ("Unable to resolve reference(s) '%s' with plugins(s) '%s', "
-                "try running 'avocado -V list %s' to see the details."
-                % ("', '" .join(self.unhandled_references),
-                   "', '".join(self.plugins),
-                   " ".join(self.unhandled_references)))
+        ref1 = "', '" .join(self.unhandled_references)
+        plugins = "', '".join(self.plugins)
+        ref2 = " ".join(self.unhandled_references)
+        return (f"Unable to resolve reference(s) '{ref1}' "
+                f"with plugins(s) '{plugins}', try running "
+                f"'avocado -V list {ref2}' to see the details.")
 
 
 class TestLoaderProxy:
@@ -86,8 +101,8 @@ class TestLoaderProxy:
             else:
                 raise ValueError
         except ValueError:
-            raise InvalidLoaderPlugin("Object %s is not an instance of "
-                                      "TestLoader" % plugin)
+            raise InvalidLoaderPlugin(f"Object {plugin} is not an instance "
+                                      f"of TestLoader")
 
     def load_plugins(self, config):
         if self._initialized_plugins:
@@ -112,13 +127,12 @@ class TestLoaderProxy:
             """
             out = ""
             for plugin in self.registered_plugins:
-                out += "  %s: %s\n" % (plugin.name,
-                                       ", ".join(_good_test_types(plugin)))
+                out += (f"  {plugin.name}: "
+                        f"{', '.join(_good_test_types(plugin))}\n")
             return out.rstrip('\n')
 
         # When running from the JobAPI there is no subcommand
         subcommand = config.get('subcommand') or 'run'
-        self.register_plugin(TapLoader)
         # Add (default) file loader if not already registered
         if FileLoader not in self.registered_plugins:
             self.register_plugin(FileLoader)
@@ -128,8 +142,7 @@ class TestLoaderProxy:
             supported_types.extend(_good_test_types(plugin))
 
         # Here is one of the few exceptions that has a hardcoded default
-        loaders = config.get("{}.loaders".format(subcommand)) or ['file',
-                                                                  '@DEFAULT']
+        loaders = config.get(f"{subcommand}.loaders") or ['file', '@DEFAULT']
         if "@DEFAULT" in loaders:  # Replace @DEFAULT with unused loaders
             idx = loaders.index("@DEFAULT")
             loaders = (loaders[:idx] + [plugin for plugin in supported_loaders
@@ -145,9 +158,9 @@ class TestLoaderProxy:
             if name in supported_types:
                 name, extra_params['allowed_test_types'] = name.split('.', 1)
             elif name not in supported_loaders:
-                raise InvalidLoaderPlugin("Unknown loader '%s'. Available "
-                                          "plugins are:\n%s"
-                                          % (name, _str_loaders()))
+                raise InvalidLoaderPlugin(f"Unknown loader '{name}'. "
+                                          f"Available plugins are:\n"
+                                          f"{ _str_loaders()}")
             if len(loaders[i]) == 2:
                 extra_params['loader_options'] = loaders[i][1]
             plugin = self.registered_plugins[supported_loaders.index(name)]
@@ -202,8 +215,8 @@ class TestLoaderProxy:
         """
         def handle_exception(plugin, details):
             # FIXME: Introduce avocado.exceptions logger and use here
-            stacktrace.log_message("Test discovery plugin %s failed: "
-                                   "%s" % (plugin, details),
+            stacktrace.log_message((f"Test discovery plugin {plugin} "
+                                    f"failed: {details}"),
                                    LOG_UI.getChild("exceptions"))
             # FIXME: Introduce avocado.traceback logger and use here
             stacktrace.log_exc_info(sys.exc_info(), LOG_UI.getChild("debug"))
@@ -262,26 +275,25 @@ class TestLoader:
             mapping = self.get_type_label_mapping()
             types = extra_params.pop("allowed_test_types")
             if len(mapping) != 1:
-                msg = ("Loader '%s' supports multiple test types but does not "
-                       "handle the 'allowed_test_types'. Either don't use "
-                       "'%s' instead of '%s.%s' or take care of the "
-                       "'allowed_test_types' in the plugin."
-                       % (self.name, self.name, self.name, types))
+                msg = (f"Loader '{self.name}' supports multiple test types "
+                       f"but does not handle the 'allowed_test_types'. "
+                       f"Either don't use '{self.name}' instead of "
+                       f"'{self.name}.{types}' or take care of the "
+                       f"'allowed_test_types' in the plugin.")
                 raise LoaderError(msg)
             elif next(iter(mapping.values())) != types:
-                raise LoaderError("Loader '%s' doesn't support test type '%s',"
-                                  " it supports only '%s'"
-                                  % (self.name, types,
-                                     next(iter(mapping.values()))))
+                raise LoaderError(f"Loader '{self.name}' doesn't support "
+                                  f"test type '{types}', it supports only "
+                                  f"'{next(iter(mapping.values()))}'")
         if "loader_options" in extra_params:
-            raise LoaderError("Loader '%s' doesn't support 'loader_options', "
-                              "please don't use --loader %s:%s"
-                              % (self.name, self.name,
-                                 extra_params.get("loader_options")))
+            raise LoaderError(f"Loader '{self.name}' doesn't support "
+                              f"'loader_options', please don't use "
+                              f"--loader {self.name}:"
+                              f"{extra_params.get('loader_options')}")
         if extra_params:
-            raise LoaderError("Loader '%s' doesn't handle extra params %s, "
-                              "please adjust your plugin to take care of them."
-                              % (self.name, extra_params))
+            raise LoaderError(f"Loader '{self.name}' doesn't handle extra "
+                              f"params {extra_params}, please adjust your "
+                              f"plugin to take care of them.")
         self.config = config
 
     def get_extra_listing(self):
@@ -330,14 +342,6 @@ class TestLoader:
         raise NotImplementedError
 
 
-class BrokenSymlink:
-    """ Dummy object to represent reference pointing to a BrokenSymlink path """
-
-
-class AccessDeniedPath:
-    """ Dummy object to represent reference pointing to a inaccessible path """
-
-
 def add_loader_options(parser, section='run'):
     arggrp = parser.add_argument_group('loader options')
     help_msg = ("Overrides the priority of the test loaders. You can specify "
@@ -355,20 +359,14 @@ def add_loader_options(parser, section='run'):
                              metavar='LOADER_NAME_OR_TEST_TYPE')
 
 
-class NotATest:
-    """
-    Class representing something that is not a test
-    """
-
-
-class SimpleFileLoader(TestLoader):
+class FileLoader(TestLoader):
 
     """
     Test loader class.
     """
 
     name = 'file'
-    NOT_TEST_STR = ("Not a supported test")
+    NOT_TEST_STR = "Not an INSTRUMENTED (avocado.Test based) test"
 
     def __init__(self, config, extra_params):
         test_type = extra_params.pop('allowed_test_types', None)
@@ -378,20 +376,25 @@ class SimpleFileLoader(TestLoader):
     @staticmethod
     def get_type_label_mapping():
         return {NotATest: 'NOT_A_TEST',
-                MissingTest: 'MISSING',
                 BrokenSymlink: 'BROKEN_SYMLINK',
-                AccessDeniedPath: 'ACCESS_DENIED'}
+                AccessDeniedPath: 'ACCESS_DENIED',
+                test.Test: 'INSTRUMENTED'}
 
     @staticmethod
     def get_decorator_mapping():
         return {NotATest: output.TERM_SUPPORT.warn_header_str,
-                MissingTest: output.TERM_SUPPORT.fail_header_str,
                 BrokenSymlink: output.TERM_SUPPORT.fail_header_str,
-                AccessDeniedPath: output.TERM_SUPPORT.fail_header_str}
+                AccessDeniedPath: output.TERM_SUPPORT.fail_header_str,
+                test.Test: output.TERM_SUPPORT.healthy_str}
 
     @staticmethod
     def _is_matching_test_class(tst, test_class):
-        return issubclass(tst, test_class)
+        if test_class is test.Test:
+            # Instrumented tests are defined as string and loaded at the
+            # execution time.
+            return isinstance(tst, str)
+        else:
+            return not isinstance(tst, str) and issubclass(tst, test_class)
 
     def discover(self, reference, which_tests=DiscoverMode.DEFAULT):
         """
@@ -474,27 +477,37 @@ class SimpleFileLoader(TestLoader):
                                               subtests_filter))
         return tests
 
-    def _make_simple_test(self, test_path, subtests_filter):
-        return self._make_test(test.SimpleTest, test_path,
-                               subtests_filter=subtests_filter,
-                               executable=test_path)
-
-    def _make_simple_or_broken_test(self, test_path, subtests_filter, make_broken):
-        if os.access(test_path, os.X_OK):
-            return self._make_simple_test(test_path, subtests_filter)
+    def _make_existing_file_tests(self, test_path, make_broken,
+                                  subtests_filter):
+        if test_path.endswith('.py'):
+            return self._make_python_file_tests(test_path, make_broken,
+                                                subtests_filter)
         else:
             return make_broken(NotATest, test_path,
                                self.NOT_TEST_STR)
 
-    def _make_existing_file_tests(self, test_path, make_broken,
-                                  subtests_filter):
-        return self._make_simple_or_broken_test(test_path, subtests_filter, make_broken)
-
-    @staticmethod
-    def _make_nonexisting_file_tests(test_path, make_broken,
-                                     subtests_filter, test_name):  # pylint: disable=W0613
-        return make_broken(NotATest, test_name, "File not found "
-                           "('%s'; '%s')" % (test_name, test_path))
+    def _make_nonexisting_file_tests(self, test_path, make_broken,
+                                     subtests_filter, test_name):
+        # Try to resolve test ID (keep compatibility)
+        test_path = os.path.join(data_dir.get_test_dir(), test_name)
+        if os.path.exists(test_path):
+            return self._make_python_file_tests(test_path, make_broken,
+                                                subtests_filter,
+                                                test_name)
+        else:
+            if not subtests_filter and ':' in test_name:
+                test_name, subtests_filter = test_name.split(':', 1)
+                test_path = os.path.join(data_dir.get_test_dir(),
+                                         test_name)
+                if os.path.exists(test_path):
+                    subtests_filter = re.compile(subtests_filter)
+                    return self._make_python_file_tests(test_path,
+                                                        make_broken,
+                                                        subtests_filter,
+                                                        test_name)
+            return make_broken(NotATest, test_name,
+                               (f"File not found ('{test_name}'; "
+                                f"'{test_path}')"))
 
     @staticmethod
     def _make_test(klass, uid, description=None, subtests_filter=None,
@@ -511,7 +524,7 @@ class SimpleFileLoader(TestLoader):
             return []
 
         if description:
-            uid = "%s: %s" % (uid, description)
+            uid = f"{uid}: {description}"
         test_arguments["name"] = uid
         return [(klass, test_arguments)]
 
@@ -550,61 +563,6 @@ class SimpleFileLoader(TestLoader):
                                                      subtests_filter,
                                                      test_name)
 
-
-class FileLoader(SimpleFileLoader):
-
-    """
-    Test loader class.
-    """
-
-    name = 'file'
-    NOT_TEST_STR = ("Not an INSTRUMENTED (avocado.Test based), PyUNITTEST ("
-                    "unittest.TestCase based) or SIMPLE (executable) test")
-
-    @staticmethod
-    def get_type_label_mapping():
-        mapping = SimpleFileLoader.get_type_label_mapping()
-        mapping.update(
-            {test.SimpleTest: 'SIMPLE',
-             test.Test: 'INSTRUMENTED'})
-        return mapping
-
-    @staticmethod
-    def get_decorator_mapping():
-        mapping = SimpleFileLoader.get_decorator_mapping()
-        mapping.update(
-            {test.SimpleTest: output.TERM_SUPPORT.healthy_str,
-             test.Test: output.TERM_SUPPORT.healthy_str})
-        return mapping
-
-    @staticmethod
-    def _is_matching_test_class(tst, test_class):
-        if test_class is test.Test:
-            # Instrumented tests are defined as string and loaded at the
-            # execution time.
-            return isinstance(tst, str)
-        else:
-            return not isinstance(tst, str) and issubclass(tst, test_class)
-
-    @staticmethod
-    def _find_python_unittests(test_path, disabled, subtests_filter):
-        result = []
-        class_methods = safeloader.find_python_unittests(test_path)
-        for klass, methods in class_methods.items():
-            if klass in disabled:
-                continue
-            if test_path.endswith(".py"):
-                test_path = test_path[:-3]
-            test_module_name = os.path.relpath(test_path)
-            test_module_name = test_module_name.replace(os.path.sep, ".")
-            candidates = [("%s.%s.%s" % (test_module_name, klass, method),
-                           tags) for (method, tags, _) in methods]
-            if subtests_filter:
-                result += [_ for _ in candidates if subtests_filter.search(_)]
-            else:
-                result += candidates
-        return result
-
     def _make_python_file_tests(self, test_path, make_broken,
                                 subtests_filter, test_name=None):
         if test_name is None:
@@ -618,7 +576,7 @@ class FileLoader(SimpleFileLoader):
                     if isinstance(test_class, str):
                         for test_method, tags, _ in info:
                             name = test_name + \
-                                ':%s.%s' % (test_class, test_method)
+                                f':{test_class}.{test_method}'
                             if (subtests_filter and
                                     not subtests_filter.search(name)):
                                 continue
@@ -629,11 +587,8 @@ class FileLoader(SimpleFileLoader):
                             test_factories.append(tst)
                 return test_factories
             else:
-                # Module does not have an avocado test or pyunittest class inside,
-                # but maybe it's a Python executable.
-                return self._make_simple_or_broken_test(test_path,
-                                                        subtests_filter,
-                                                        make_broken)
+                return make_broken(NotATest, test_path,
+                                   self.NOT_TEST_STR)
 
         # Since a lot of things can happen here, the broad exception is
         # justified. The user will get it unadulterated anyway, and avocado
@@ -642,67 +597,8 @@ class FileLoader(SimpleFileLoader):
             if isinstance(details, KeyboardInterrupt):
                 raise  # Don't ignore ctrl+c
             else:
-                return self._make_simple_or_broken_test(test_path,
-                                                        subtests_filter,
-                                                        make_broken)
-
-    def _make_existing_file_tests(self, test_path, make_broken,
-                                  subtests_filter):
-        if test_path.endswith('.py'):
-            return self._make_python_file_tests(test_path, make_broken,
-                                                subtests_filter)
-        else:
-            return self._make_simple_or_broken_test(test_path,
-                                                    subtests_filter,
-                                                    make_broken)
-
-    def _make_nonexisting_file_tests(self, test_path, make_broken,
-                                     subtests_filter, test_name):
-        # Try to resolve test ID (keep compatibility)
-        test_path = os.path.join(data_dir.get_test_dir(), test_name)
-        if os.path.exists(test_path):
-            return self._make_python_file_tests(test_path, make_broken,
-                                                subtests_filter,
-                                                test_name)
-        else:
-            if not subtests_filter and ':' in test_name:
-                test_name, subtests_filter = test_name.split(':', 1)
-                test_path = os.path.join(data_dir.get_test_dir(),
-                                         test_name)
-                if os.path.exists(test_path):
-                    subtests_filter = re.compile(subtests_filter)
-                    return self._make_python_file_tests(test_path,
-                                                        make_broken,
-                                                        subtests_filter,
-                                                        test_name)
-            return make_broken(NotATest, test_name, "File not found "
-                               "('%s'; '%s')" % (test_name, test_path))
-
-
-class TapLoader(SimpleFileLoader):
-    """
-    Test Anything Protocol loader class
-    """
-    name = "tap"
-
-    @staticmethod
-    def get_type_label_mapping():
-        mapping = SimpleFileLoader.get_type_label_mapping()
-        mapping.update(
-            {test.TapTest: 'TAP'})
-        return mapping
-
-    @staticmethod
-    def get_decorator_mapping():
-        mapping = SimpleFileLoader.get_decorator_mapping()
-        mapping.update(
-            {test.TapTest: output.TERM_SUPPORT.healthy_str})
-        return mapping
-
-    def _make_simple_test(self, test_path, subtests_filter):
-        return self._make_test(test.TapTest, test_path,
-                               subtests_filter=subtests_filter,
-                               executable=test_path)
+                return make_broken(NotATest, test_path,
+                                   self.NOT_TEST_STR)
 
 
 loader = TestLoaderProxy()
