@@ -69,8 +69,8 @@ class ConfigFileNotFound(SettingsError):
         self.path_list = path_list
 
     def __str__(self):
-        return ("Could not find the avocado config file after looking in: %s" %
-                self.path_list)
+        return (f"Could not find the avocado config file after looking in: "
+                f"{self.path_list}")
 
 
 class DuplicatedNamespace(SettingsError):
@@ -89,7 +89,8 @@ class ConfigOption:
     def __init__(self, namespace, help_msg, key_type=str, default=None,
                  parser=None, short_arg=None, long_arg=None,
                  positional_arg=False, choices=None, nargs=None,
-                 metavar=None, required=None, action=None, argparse_type=None):
+                 metavar=None, required=None, action=None, argparse_type=None,
+                 argparse_help_msg=None):
         self.namespace = namespace
         self.help_msg = help_msg
         self.key_type = key_type
@@ -105,6 +106,7 @@ class ConfigOption:
         self._action = action
         self._value = None
         self._argparse_type = argparse_type
+        self._argparse_help_msg = argparse_help_msg
 
         self._update_argparser()
 
@@ -160,6 +162,16 @@ class ConfigOption:
     def argparse_type(self, value):
         self._argparse_type = value
 
+    @property
+    def argparse_help_msg(self):
+        if self._argparse_help_msg is not None:
+            return self._argparse_help_msg
+        return self.help_msg
+
+    @argparse_help_msg.setter
+    def argparse_help_msg(self, value):
+        self._argparse_help_msg = value
+
     @property
     def metavar(self):
         if self.positional_arg:
@@ -169,7 +181,7 @@ class ConfigOption:
 
     @property
     def arg_parse_args(self):
-        args = {'help': self.help_msg,
+        args = {'help': self.argparse_help_msg,
                 'default': None}
 
         if self.nargs:
@@ -202,7 +214,7 @@ class ConfigOption:
         if isinstance(value, list):
             return value
 
-        raise ValueError("{} could not be converted into a list".format(value))
+        raise ValueError(f"{value} could not be converted into a list")
 
     def _update_argparser(self):
         if not self.parser:
@@ -216,7 +228,7 @@ class ConfigOption:
     def add_argparser(self, parser, long_arg, short_arg=None,
                       positional_arg=False, choices=None, nargs=None,
                       metavar=None, required=None, action=None,
-                      argparse_type=None):
+                      argparse_type=None, argparse_help_msg=None):
         """Add an command-line argparser to this option."""
 
         self.parser = parser
@@ -229,6 +241,7 @@ class ConfigOption:
         self.required = required
         self._action = action
         self._argparse_type = argparse_type
+        self._argparse_help_msg = argparse_help_msg
 
         self._update_argparser()
 
@@ -343,7 +356,8 @@ class Settings:
                                 short_arg=None, positional_arg=False,
                                 choices=None, nargs=None, metavar=None,
                                 required=None, action=None,
-                                allow_multiple=False, argparse_type=None):
+                                allow_multiple=False, argparse_type=None,
+                                help_msg=None):
         """Add a command-line argument parser to an existing option.
 
         This method is useful to add a parser when the option is registered
@@ -407,6 +421,12 @@ class Settings:
             will, for instance, split a comma separated list may be used,
             resulting in command line users being able to provide convenient
             input.
+
+        help_msg : str
+            A help message, different from the original ConfigOption
+            help message, to be shown on the command line.  To be used when
+            the command line usage and the original help message do not make
+            sense together.
         """
         if not any([long_arg, short_arg, positional_arg]):
             raise SettingsError("To add an argument parser to an option, it "
@@ -417,7 +437,7 @@ class Settings:
         try:
             option = self._namespaces[namespace]
         except KeyError:
-            msg = "Namespace not found: {}".format(namespace)
+            msg = f"Namespace not found: {namespace}"
             raise NamespaceNotRegistered(msg)
 
         if option and option.parser and not allow_multiple:
@@ -426,7 +446,7 @@ class Settings:
 
         option.add_argparser(parser, long_arg, short_arg, positional_arg,
                              choices, nargs, metavar, required, action,
-                             argparse_type)
+                             argparse_type, help_msg)
 
     def as_dict(self, regex=None):
         """Return an dictionary with the current active settings.
@@ -508,7 +528,7 @@ class Settings:
         for section in self.config:
             items = self.config.items(section)
             for key, value in items:
-                namespace = "{}.{}".format(section, key)
+                namespace = f"{section}.{key}"
                 self.update_option(namespace, value, convert=True)
 
     def process_config_path(self, path):
@@ -621,12 +641,12 @@ class Settings:
                   action) are only necessary if you would like to add a
                   command-line option.
         """
-        namespace = "{}.{}".format(section, key)
+        namespace = f"{section}.{key}"
         # Check if namespace is already registered
         if namespace in self._namespaces:
             if not allow_multiple:
-                msg = 'Key "{}" already registered under section "{}"'.format(key,
-                                                                              section)
+                msg = (f'Key "{key}" already registered under '
+                       f'section "{section}"')
                 raise DuplicatedNamespace(msg)
             else:
                 self.add_argparser_to_option(namespace, parser, long_arg,
