@@ -19,13 +19,10 @@ from uuid import uuid4
 from avocado.core.dispatcher import RunnerDispatcher
 from avocado.core.exceptions import (JobTestSuiteReferenceResolutionError,
                                      OptionValidationError)
-from avocado.core.loader import (DiscoverMode, LoaderError,
-                                 LoaderUnhandledReferenceError, loader)
 from avocado.core.parser import HintParser
 from avocado.core.resolver import ReferenceResolutionResult, resolve
 from avocado.core.settings import settings
-from avocado.core.tags import filter_test_tags, filter_test_tags_runnable
-from avocado.core.test import DryRunTest
+from avocado.core.tags import filter_test_tags_runnable
 from avocado.core.tree import TreeNode
 from avocado.core.varianter import Varianter, is_empty_variant
 
@@ -78,7 +75,6 @@ def resolutions_to_runnables(resolutions, config):
                                                  include_empty,
                                                  include_empty_key):
                     continue
-            runnable.config = config
             result.append(runnable)
     return result
 
@@ -99,11 +95,6 @@ class TestSuite:
         if config:
             self.config.update(config)
 
-        # Update the config of runnables.
-        if self.config.get('run.test_runner') == 'nrunner' and self.tests:
-            for test in self.tests:
-                test.config.update(self.config)
-
         self._variants = None
         self._references = None
         self._runner = None
@@ -146,44 +137,6 @@ class TestSuite:
         if self.config.get('run.test_runner') == 'nrunner':
             for runnable in self.tests:
                 runnable.kind = 'dry-run'
-        else:
-            for i in range(self.size):
-                self.tests[i] = [DryRunTest, self.tests[i][1]]
-
-    @classmethod
-    def _from_config_with_loader(cls, config, name=None):
-        references = config.get('resolver.references')
-        ignore_missing = config.get('run.ignore_missing_references')
-        verbose = config.get('core.verbose')
-        subcommand = config.get('subcommand')
-
-        # To-be-removed: For some reason, avocado list will display more tests
-        # if in verbose mode. IMO, this is a little inconsistent with the 'run'
-        # command.  This hack was needed to make one specific test happy.
-        tests_mode = DiscoverMode.DEFAULT
-        if subcommand == 'list':
-            if verbose:
-                tests_mode = DiscoverMode.ALL
-            else:
-                tests_mode = DiscoverMode.AVAILABLE
-
-        try:
-            loader.load_plugins(config)
-            tests = loader.discover(references,
-                                    force=ignore_missing,
-                                    which_tests=tests_mode)
-            if config.get("filter.by_tags.tags"):
-                tests = filter_test_tags(
-                    tests,
-                    config.get("filter.by_tags.tags"),
-                    config.get("filter.by_tags.include_empty"),
-                    config.get('filter.by_tags.include_empty_key'))
-        except (LoaderUnhandledReferenceError, LoaderError) as details:
-            raise TestSuiteError(details)
-
-        if name is None:
-            name = str(uuid4())
-        return cls(name=name, config=config, tests=tests)
 
     @classmethod
     def _from_config_with_resolver(cls, config, name=None):
@@ -303,8 +256,8 @@ class TestSuite:
                 try:
                     variants.parse(self.config)
                 except (IOError, ValueError) as details:
-                    raise OptionValidationError("Unable to parse "
-                                                "variant: %s" % details)
+                    raise OptionValidationError(f"Unable to parse variant: "
+                                                f"{details}")
             self._variants = variants
         return self._variants
 
@@ -366,14 +319,15 @@ class TestSuite:
         """
         suite_config = config
         config = settings.as_dict()
-        config.update(suite_config)
         if job_config:
             config.update(job_config)
+        config.update(suite_config)
         runner = config.get('run.test_runner')
         if runner == 'nrunner':
             suite = cls._from_config_with_resolver(config, name)
         else:
-            suite = cls._from_config_with_loader(config, name)
+            raise TestSuiteError(f'Suite creation for runner "{runner}" '
+                                 f'is not supported')
 
         if not config.get('run.ignore_missing_references'):
             if not suite.tests:
