@@ -1,7 +1,7 @@
 from copy import deepcopy
 
 from avocado.core.dependencies.resolver import DependencyResolver
-from avocado.core.nrunner import RUNNERS_REGISTRY_PYTHON_CLASS, Task
+from avocado.core.nrunner.task import Task
 from avocado.core.test_id import TestID
 from avocado.core.varianter import dump_variant
 
@@ -39,11 +39,10 @@ class RuntimeTask:
 
     def __repr__(self):
         if self.status is None:
-            return '<RuntimeTask Task Identifier: "%s">' % self.task.identifier
+            return f'<RuntimeTask Task Identifier: "{self.task.identifier}">'
         else:
-            return '<RuntimeTask Task Identifier: "%s" Status: "%s">' % (
-                self.task.identifier,
-                self.status)
+            return (f'<RuntimeTask Task Identifier: "{self.task.identifier}"'
+                    f'Status: "{self.status}">')
 
     def __hash__(self):
         if self.task.category == "test":
@@ -82,7 +81,7 @@ class RuntimeTask:
 
         # create test ID
         if test_suite_name:
-            prefix = "{}-{}".format(test_suite_name, index)
+            prefix = f"{test_suite_name}-{index}"
         else:
             prefix = index
         test_id = TestID(prefix,
@@ -95,7 +94,6 @@ class RuntimeTask:
         # handles the test task
         task = Task(runnable,
                     identifier=test_id,
-                    known_runners=RUNNERS_REGISTRY_PYTHON_CLASS,
                     status_uris=status_server_uri,
                     job_id=job_id)
         return cls(task)
@@ -125,8 +123,8 @@ class RuntimeTask:
         dependencies_runtime_tasks = []
         # creates the tasks and runtime tasks for the dependencies
         for dependency_runnable in dependencies_runnables:
-            name = '%s-%s' % (dependency_runnable.kind,
-                              dependency_runnable.kwargs.get('name'))
+            name = (f"{dependency_runnable.kind}-"
+                    f"{dependency_runnable.kwargs.get('name')}")
             prefix = 0
             # the human UI works with TestID objects, so we need to
             # use it to name Task
