@@ -21,28 +21,22 @@ framework tests.
 import asyncio
 import functools
 import inspect
-import io
-import logging
 import os
-import pipes
-import re
 import shutil
 import sys
 import tempfile
 import time
 import unittest
 import warnings
-from difflib import unified_diff
 
-from avocado.core import exceptions, output, parameters, sysinfo, tapparser
-from avocado.core.decorators import skip
+from avocado.core import exceptions, parameters
 from avocado.core.output import LOG_JOB
 from avocado.core.settings import settings
 from avocado.core.test_id import TestID
 from avocado.core.version import VERSION
 from avocado.utils import asset, astring, data_structures, genio
 from avocado.utils import path as utils_path
-from avocado.utils import process, stacktrace
+from avocado.utils import stacktrace
 
 #: Environment variable used to store the location of a temporary
 #: directory which is preserved across all tests execution (usually in
@@ -59,31 +53,6 @@ TEST_STATE_ATTRIBUTES = ('name', 'logdir', 'logfile',
                          'tags', 'timeout', 'whiteboard', 'phase')
 
 
-class RawFileHandler(logging.FileHandler):
-
-    """
-    File Handler that doesn't include arbitrary characters to the
-    logged stream but still respects the formatter.
-    """
-
-    def emit(self, record):
-        """
-        Modifying the original emit() to avoid including a new line
-        in streams that should be logged in its purest form, like in
-        stdout/stderr recordings.
-        """
-        if self.stream is None:
-            self.stream = self._open()
-        try:
-            msg = self.format(record)
-            stream = self.stream
-            stream.write(astring.to_text(msg, self.encoding,
-                                         'xmlcharrefreplace'))
-            self.flush()
-        except Exception:  # pylint: disable=W0703
-            self.handleError(record)
-
-
 class TestData:
 
     """
@@ -107,12 +76,12 @@ class TestData:
             file_datadir = self.filename + '.data'
         self._data_sources_mapping = {
             "variant": [lambda: file_datadir,
-                        lambda: "%s.%s" % (self.__class__.__name__,
-                                           self._testMethodName),
+                        lambda: (f"{self.__class__.__name__}."
+                                 f"{self._testMethodName}"),
                         lambda: self.name.variant],
             "test": [lambda: file_datadir,
-                     lambda: "%s.%s" % (self.__class__.__name__,
-                                        self._testMethodName)],
+                     lambda: (f"{self.__class__.__name__}."
+                              f"{self._testMethodName}")],
             "file": [lambda: file_datadir]
         }
 
@@ -197,17 +166,17 @@ class TestData:
                     path = os.path.join(datadir, filename)
                 if not must_exist:
                     self.log.debug(log_fmt, filename, path,
-                                   ("assumed to be located at %s source "
-                                    "dir" % attempt_source))
+                                   (f"assumed to be located at "
+                                    f"{attempt_source} source dir"))
                     return path
                 else:
                     if os.path.exists(path):
                         self.log.debug(log_fmt, filename, path,
-                                       "found at %s source dir" % attempt_source)
+                                       f"found at {attempt_source} source dir")
                         return path
 
         self.log.debug(log_fmt, filename, "NOT FOUND",
-                       "data sources: %s" % ', '.join(sources))
+                       f"data sources: {', '.join(sources)}")
 
 
 class Test(unittest.TestCase, TestData):
@@ -278,18 +247,6 @@ class Test(unittest.TestCase, TestData):
             self.__base_logdir_tmp = tempfile.TemporaryDirectory(prefix=prefix)
             self.__base_logdir = self.__base_logdir_tmp.name
 
-        if self._config.get("run.test_runner") == 'nrunner':
-            logdir = self.__base_logdir
-            self.__logdir = logdir
-        else:
-            self.__base_logdir = os.path.join(self.__base_logdir, 'test-results')
-            logdir = os.path.join(self.__base_logdir, self.name.str_filesystem)
-
-            if os.path.exists(logdir):
-                raise exceptions.TestSetupFail("Log dir already exists, this "
-                                               "should never happen: %s"
-                                               % logdir)
-            self.__logdir = utils_path.init_dir(logdir)
         self.__logfile = os.path.join(self.logdir, 'debug.log')
 
         self._stdout_file = os.path.join(self.logdir, 'stdout')
@@ -299,21 +256,11 @@ class Test(unittest.TestCase, TestData):
 
         self.__outputdir = utils_path.init_dir(self.logdir, 'data')
 
-        self.__sysinfo_enabled = self._config.get('sysinfo.collect.per_test',
-                                                  False)
-
-        if self.__sysinfo_enabled:
-            self.__sysinfodir = utils_path.init_dir(self.logdir, 'sysinfo')
-            self.__sysinfo_logger = sysinfo.SysInfo(basedir=self.__sysinfodir)
-
         self.__log = LOG_JOB
         original_log_warn = self.log.warning
         self.__log_warn_used = False
         self.log.warn = self.log.warning = record_and_warn
 
-        # Initialized by _start_logging and terminated by _stop_logging
-        self._file_handler = None
-
         self.log.info('INIT %s', self.name)
 
         paths = ['/test/*']
@@ -391,7 +338,7 @@ class Test(unittest.TestCase, TestData):
         """
         Path to this test's logging dir
         """
-        return self.__logdir
+        return self.__base_logdir
 
     @property
     def logfile(self):
@@ -452,7 +399,7 @@ class Test(unittest.TestCase, TestData):
         env_var = COMMON_TMPDIR_NAME
         path = os.environ.get(env_var)
         if path is None:
-            msg = 'Environment Variable %s is not set.' % env_var
+            msg = f'Environment Variable {env_var} is not set.'
             raise EnvironmentError(msg)
         return path
 
@@ -494,9 +441,9 @@ class Test(unittest.TestCase, TestData):
         Override the runner_queue
         """
         if self.__runner_queue is not None:
-            raise RuntimeError("Overriding of runner_queue multiple "
-                               "times is not allowed -> old=%s new=%s"
-                               % (self.__runner_queue, runner_queue))
+            raise RuntimeError(f"Overriding of runner_queue multiple times "
+                               f"is not allowed -> old={self.__runner_queue} "
+                               f"new={runner_queue}")
         self.__runner_queue = runner_queue
 
     @property
@@ -538,7 +485,7 @@ class Test(unittest.TestCase, TestData):
         return str(self.name)
 
     def __repr__(self):
-        return "Test(%r)" % self.name
+        return f"Test({self.name!r})"
 
     def _tag_start(self):
         self.log.info('START %s', self.name)
@@ -581,141 +528,12 @@ class Test(unittest.TestCase, TestData):
                            in self.__params.iteritems()]
         return state
 
-    def _register_log_file_handler(self, logger, formatter, filename,
-                                   log_level=logging.DEBUG, raw=False):
-        if raw:
-            file_handler = RawFileHandler(filename=filename,
-                                          encoding=astring.ENCODING)
-        else:
-            file_handler = logging.FileHandler(filename=filename)
-        file_handler.setLevel(log_level)
-        file_handler.setFormatter(formatter)
-        logger.addHandler(file_handler)
-        self._logging_handlers[logger.name] = file_handler
-
-    def _start_logging(self):
-        """
-        Simple helper for adding a file logger to the main logger.
-        """
-        self._file_handler = logging.FileHandler(filename=self.logfile)
-        self._file_handler.setLevel(logging.DEBUG)
-
-        fmt = '%(asctime)s %(levelname)-5.5s| %(message)s'
-        formatter = logging.Formatter(fmt=fmt, datefmt='%H:%M:%S')
-
-        self._file_handler.setFormatter(formatter)
-        self.log.addHandler(self._file_handler)
-        self.log.propagate = False
-
-        # Adding the test log FileHandler to the Avocado's main logger so
-        # that everything logged while the test is running, for every logger,
-        # also makes its way into the test log file
-        logger = logging.getLogger('avocado')
-        logger.addHandler(self._file_handler)
-
-        stream_fmt = '%(message)s'
-        stream_formatter = logging.Formatter(fmt=stream_fmt)
-
-        log_test_stdout = LOG_JOB.getChild("stdout")
-        log_test_stderr = LOG_JOB.getChild("stderr")
-        log_test_output = LOG_JOB.getChild("output")
-
-        self._register_log_file_handler(log_test_stdout,
-                                        stream_formatter,
-                                        self._stdout_file,
-                                        raw=True)
-        self._register_log_file_handler(log_test_stderr,
-                                        stream_formatter,
-                                        self._stderr_file,
-                                        raw=True)
-        self._register_log_file_handler(log_test_output,
-                                        stream_formatter,
-                                        self._output_file,
-                                        raw=True)
-
-        if isinstance(sys.stdout, output.LoggingFile):
-            sys.stdout.add_logger(log_test_stdout)
-        if isinstance(sys.stderr, output.LoggingFile):
-            sys.stderr.add_logger(log_test_stderr)
-
-    def _stop_logging(self):
-        """
-        Stop the logging activity of the test by cleaning the logger handlers.
-        """
-        self.log.removeHandler(self._file_handler)
-        if isinstance(sys.stderr, output.LoggingFile):
-            sys.stderr.rm_logger(LOG_JOB.getChild("stderr"))
-        if isinstance(sys.stdout, output.LoggingFile):
-            sys.stdout.rm_logger(LOG_JOB.getChild("stdout"))
-        for name, handler in self._logging_handlers.items():
-            logging.getLogger(name).removeHandler(handler)
-
-    def _check_reference(self, produced_file_path, reference_file_name,
-                         diff_file_name, child_log_name, name='Content'):
-        '''
-        Compares the file produced by the test with the reference file
-
-        :param produced_file_path: the location of the file that was produced
-                                   by this test execution
-        :type produced_file_path: str
-        :param reference_file_name: the name of the file that will compared
-                                    with the content produced by this test
-        :type reference_file_name: str
-        :param diff_file_name: in case of differences between the produced
-                               and reference file, a file with this name will
-                               be saved to the test results directory, with
-                               the differences in unified diff format
-        :type diff_file_name: str
-        :param child_log_name: the name of a logger, child of :data:`LOG_JOB`,
-                               to be used when logging the content differences
-        :type child_log_name: str
-        :param name: optional parameter for a descriptive name of the type of
-                     content being checked here
-        :type name: str
-        :returns: True if the check was performed (there was a reference file) and
-                  was successful, and False otherwise (there was no such reference
-                  file and thus no check was performed).
-        :raises: :class:`exceptions.TestFail` when the check is performed and fails
-        '''
-        reference_path = self.get_data(reference_file_name)
-        if reference_path is not None:
-            expected = genio.read_file(reference_path)
-            actual = genio.read_file(produced_file_path)
-            diff_path = os.path.join(self.logdir, diff_file_name)
-
-            fmt = '%(message)s'
-            formatter = logging.Formatter(fmt=fmt)
-            log_diff = LOG_JOB.getChild(child_log_name)
-            self._register_log_file_handler(log_diff,
-                                            formatter,
-                                            diff_path)
-
-            diff = unified_diff(expected.splitlines(), actual.splitlines(),
-                                fromfile=reference_path,
-                                tofile=produced_file_path)
-            diff_content = []
-            for diff_line in diff:
-                diff_content.append(diff_line.rstrip('\n'))
-
-            if diff_content:
-                self.log.debug('%s Diff:', name)
-                for line in diff_content:
-                    log_diff.debug(line)
-                self.fail('Actual test %s differs from expected one' % name)
-            else:
-                return True
-        return False
-
     def _run_test(self):
         """
         Auxiliary method to run setup and test method.
         """
         self._tag_start()
         testMethod = getattr(self, self._testMethodName)
-        if self._config.get("run.test_runner") != 'nrunner':
-            self._start_logging()
-        if self.__sysinfo_enabled:
-            self.__sysinfo_logger.start()
         skip_test_condition = getattr(testMethod, '__skip_test_condition__', False)
         skip_test_condition_negate = getattr(testMethod, '__skip_test_condition_negate__', False)
         if skip_test_condition:
@@ -761,7 +579,7 @@ class Test(unittest.TestCase, TestData):
                 stacktrace.log_exc_info(sys.exc_info(), logger=LOG_JOB)
                 details = sys.exc_info()[1]
                 if not isinstance(details, Exception):  # Avoid passing nasty exc
-                    details = exceptions.TestError("%r: %s" % (details, details))
+                    details = exceptions.TestError(f"{details!r}: {details}")
                 self.log.debug("Local variables:")
                 local_vars = inspect.trace()[1][0].f_locals
                 for key, value in local_vars.items():
@@ -780,11 +598,10 @@ class Test(unittest.TestCase, TestData):
                 self.tearDown()
         except exceptions.TestSkipError as details:
             stacktrace.log_exc_info(sys.exc_info(), logger=LOG_JOB)
-            skip_illegal_msg = ('Using skip decorators in tearDown() '
-                                'is not allowed in '
-                                'avocado, you must fix your '
-                                'test. Original skip exception: %s' %
-                                details)
+            skip_illegal_msg = (f'Using skip decorators in tearDown() '
+                                f'is not allowed in '
+                                f'avocado, you must fix your '
+                                f'test. Original skip exception: {details}')
             raise exceptions.TestError(skip_illegal_msg)
         except exceptions.TestCancel:
             stacktrace.log_exc_info(sys.exc_info(), logger=LOG_JOB)
@@ -803,8 +620,6 @@ class Test(unittest.TestCase, TestData):
         os.environ['AVOCADO_TEST_LOGDIR'] = self.logdir
         os.environ['AVOCADO_TEST_LOGFILE'] = self.logfile
         os.environ['AVOCADO_TEST_OUTPUTDIR'] = self.outputdir
-        if self.__sysinfo_enabled:
-            os.environ['AVOCADO_TEST_SYSINFODIR'] = self.__sysinfodir
 
     def _catch_test_status(self, method):
         """Wrapper around test methods for catching and logging failures."""
@@ -849,14 +664,10 @@ class Test(unittest.TestCase, TestData):
         self._catch_test_status(self._tearDown)
         whiteboard_file = os.path.join(self.logdir, 'whiteboard')
         genio.write_file(whiteboard_file, self.whiteboard)
-        if self.__sysinfo_enabled:
-            self.__sysinfo_logger.end(self.__status)
         self.__phase = 'FINISHED'
         self._tag_end()
         self._report()
         self.log.info("")
-        if self._config.get("run.test_runner") != 'nrunner':
-            self._stop_logging()
 
     def _report(self):
         """
@@ -991,7 +802,7 @@ class Test(unittest.TestCase, TestData):
                                                      asset_hash)
             except OSError as e:
                 if cancel_on_missing:
-                    self.cancel("Missing asset {}".format(name))
+                    self.cancel(f"Missing asset {name}")
                 raise e
 
         asset_obj = asset.Asset(name, asset_hash, algorithm, locations,
@@ -1008,7 +819,7 @@ class Test(unittest.TestCase, TestData):
             # the asset
             if cancel_on_missing:
                 # cancel when requested
-                self.cancel("Missing asset {}".format(name))
+                self.cancel(f"Missing asset {name}")
             # otherwise re-throw OSError
             raise e
 
@@ -1026,252 +837,3 @@ class Test(unittest.TestCase, TestData):
 
     def __del__(self):
         self._cleanup()
-
-
-class SimpleTest(Test):
-
-    """
-    Run an arbitrary command that returns either 0 (PASS) or !=0 (FAIL).
-    """
-
-    DATA_SOURCES = ["variant", "file"]
-
-    def __init__(self, name, params=None, base_logdir=None, config=None,
-                 executable=None):
-        if executable is None:
-            executable = name.name
-        self._filename = executable
-        super().__init__(name=name, params=params,
-                         base_logdir=base_logdir, config=config)
-        # Access workdir to initialize it, given that it's lazy
-        _ = self.workdir
-
-        # Maximal allowed file name length is 255
-        file_datadir = None
-        if (self.filename is not None and
-                len(os.path.basename(self.filename)) < 251):
-            file_datadir = self.filename + '.data'
-        self._data_sources_mapping = {"variant": [lambda: file_datadir,
-                                                  lambda: self.name.variant],
-                                      "file": [lambda: file_datadir]}
-        self._command = None
-        if self.filename is not None:
-            self._command = pipes.quote(self.filename)
-
-    @property
-    def filename(self):
-        """
-        Returns the name of the file (path) that holds the current test
-        """
-        return os.path.abspath(self._filename)
-
-    def _log_detailed_cmd_info(self, result):
-        """
-        Log detailed command information.
-
-        :param result: :class:`avocado.utils.process.CmdResult` instance.
-        """
-        self.log.info("Detailed information about the executed command:")
-        self.log.info("  Exit status: %s", result.exit_status)
-        self.log.info("  Duration: %s", result.duration)
-        self.log.info("  STDOUT: %s", result.stdout_text.strip())
-        self.log.info("  STDERR: %s", result.stderr_text.strip())
-
-    def _cmd_error_to_test_failure(self, cmd_error):
-        failure_fields = self._config.get('simpletests.status.failure_fields')
-        msgs = []
-        if 'status' in failure_fields:
-            msgs.append("Exited with status: '%u'" % cmd_error.result.exit_status)
-        if 'stdout' in failure_fields:
-            msgs.append("stdout: %r" % cmd_error.result.stdout_text)
-        if 'stderr' in failure_fields:
-            msgs.append("stderr: %r" % cmd_error.result.stdout_text)
-        return ", ".join(msgs)
-
-    def _execute_cmd(self):
-        """
-        Run the executable, and log its detailed execution.
-        """
-        try:
-            test_params = dict([(str(key), str(val)) for _, key, val in
-                                self.params.iteritems()])
-
-            input_encoding = self._config.get('core.input_encoding')
-            result = process.run(self._command,
-                                 verbose=True,
-                                 env=test_params,
-                                 encoding=input_encoding)
-
-            self._log_detailed_cmd_info(result)
-        except process.CmdError as details:
-            self._log_detailed_cmd_info(details.result)
-            test_failure = self._cmd_error_to_test_failure(details)
-            raise exceptions.TestFail(test_failure)
-
-        warn_regex = self._config.get('simpletests.status.warn_regex')
-        warn_location = self._config.get('simpletests.status.warn_location')
-        skip_regex = self._config.get('simpletests.status.skip_regex')
-        skip_location = self._config.get('simpletests.status.skip_location')
-
-        # Keeping compatibility with 'avocado_warn' libexec
-        for regex in [warn_regex, r'^\d\d:\d\d:\d\d WARN \|']:
-            warn_msg = ("Test passed but there were warnings on %s during "
-                        "execution. Check the log for details.")
-            if regex is not None:
-                re_warn = re.compile(regex, re.MULTILINE)
-                if warn_location in ['all', 'stdout']:
-                    if re_warn.search(result.stdout_text):
-                        raise exceptions.TestWarn(warn_msg % 'stdout')
-
-                if warn_location in ['all', 'stderr']:
-                    if re_warn.search(result.stderr_text):
-                        raise exceptions.TestWarn(warn_msg % 'stderr')
-
-        if skip_regex is not None:
-            re_skip = re.compile(skip_regex, re.MULTILINE)
-            skip_msg = ("Test passed but %s indicates test was skipped. "
-                        "Check the log for details.")
-
-            if skip_location in ['all', 'stdout']:
-                if re_skip.search(result.stdout_text):
-                    raise exceptions.TestSkipError(skip_msg % 'stdout')
-
-            if skip_location in ['all', 'stderr']:
-                if re_skip.search(result.stderr_text):
-                    raise exceptions.TestSkipError(skip_msg % 'stderr')
-
-    def test(self):
-        """
-        Run the test and postprocess the results
-        """
-        self._execute_cmd()
-
-
-class TapTest(SimpleTest):
-
-    """
-    Run a test command as a TAP test.
-    """
-
-    def _execute_cmd(self):
-        try:
-            test_params = {
-                str(key): str(val)
-                for _, key, val in self.params.iteritems()
-            }
-
-            input_encoding = self._config.get('core.input_encoding')
-            result = process.run(self._command,
-                                 verbose=True,
-                                 env=test_params,
-                                 encoding=input_encoding)
-
-            self._log_detailed_cmd_info(result)
-        except process.CmdError as details:
-            self._log_detailed_cmd_info(details.result)
-            raise exceptions.TestFail(details)
-
-        if result.exit_status != 0:
-            self.fail('TAP Test execution returned a '
-                      'non-0 exit code (%s)' % result)
-        parser = tapparser.TapParser(io.StringIO(result.stdout_text))
-        fail = 0
-        count = 0
-        bad_errormsg = 'there were test failures'
-        for event in parser.parse():
-            if isinstance(event, tapparser.TapParser.Error):
-                self.error('TAP parsing error: ' + event.message)
-                continue
-            if isinstance(event, tapparser.TapParser.Bailout):
-                self.error(event.message)
-                continue
-            if isinstance(event, tapparser.TapParser.Test):
-                bad = event.result in (tapparser.TestResult.XPASS, tapparser.TestResult.FAIL)
-                if event.result != tapparser.TestResult.SKIP:
-                    count += 1
-                if bad:
-                    self.log.error('%s %s %s', event.result.name, event.number, event.name)
-                    fail += 1
-                    if event.result == tapparser.TestResult.XPASS:
-                        bad_errormsg = 'there were test failures or unexpected passes'
-                else:
-                    self.log.info('%s %s %s', event.result.name, event.number, event.name)
-
-        if not count:
-            raise exceptions.TestSkipError('no tests were run')
-        if fail:
-            self.fail(bad_errormsg)
-
-
-class MockingTest(Test):
-
-    """
-    Class intended as generic substitute for avocado tests which will
-    not be executed for some reason. This class is expected to be
-    overridden by specific reason-oriented sub-classes.
-    """
-
-    def __init__(self, *args, **kwargs):
-        """
-        This class substitutes other classes. Let's just ignore the remaining
-        arguments and only set the ones supported by avocado.Test
-        """
-        super_kwargs = {}
-        args = list(reversed(args))
-        for arg in ["methodName", "name", "params", "base_logdir", "config",
-                    "runner_queue"]:
-            if arg in kwargs:
-                super_kwargs[arg] = kwargs[arg]
-            elif args:
-                super_kwargs[arg] = args.pop()
-        # The methodName might not exist, make sure it's self.test
-        super_kwargs["methodName"] = "test"
-        super().__init__(**super_kwargs)
-
-    def test(self):
-        pass
-
-
-class TimeOutSkipTest(MockingTest):
-
-    """
-    Skip test due job timeout.
-
-    This test is skipped due a job timeout.
-    It will never have a chance to execute.
-    """
-
-    @skip('Test skipped due a job timeout!')
-    def test(self):
-        pass
-
-
-class DryRunTest(MockingTest):
-
-    """
-    Fake test which logs itself and reports as CANCEL
-    """
-
-    def __init__(self, *args, **kwargs):
-        if 'modulePath' in kwargs:
-            self._filename = kwargs.pop('modulePath')
-        if self._filename is None:
-            self._filename = kwargs["name"].name
-        super().__init__(**kwargs)
-
-    def setUp(self):
-        self.log.info("Test params:")
-        for path, key, value in self.params.iteritems():
-            self.log.info("%s:%s ==> %s", path, key, value)
-        self.cancel('Test cancelled due to --dry-run')
-
-    @property
-    def filename(self):
-        try:
-            source = os.path.abspath(self._filename)
-            if os.path.exists(source):
-                return source
-            else:
-                return None
-        except AttributeError:
-            return None
