@@ -21,7 +21,7 @@ import os
 from datetime import datetime
 
 from avocado.core import exit_codes, safeloader
-from avocado.core.nrunner import Runnable
+from avocado.core.nrunner.runnable import Runnable
 from avocado.core.output import LOG_UI
 from avocado.core.plugin_interfaces import CLICmd, JobPreTests
 from avocado.core.settings import settings
@@ -261,14 +261,19 @@ class FetchAssetJob(JobPreTests):  # pylint: disable=R0903
         candidates = []
         for suite in job.test_suites:
             for test in suite.tests:
-                # ignore nrunner/resolver based test suites that contain
-                # runnable, because the requirements resolution planned is
-                # completely different from the traditional job runner
+                # nrunner/resolver based test should describe their requirements
+                # explicitly using docstring statements.  But, they can still
+                # benefit from the parsing of "fetch_asset()" calls just like
+                # the legacy runner.
                 if isinstance(test, Runnable):
-                    continue
+                    if test.kind == 'avocado-instrumented':
+                        module_path, klass_method = test.uri.split(':', 1)
+                        klass, method = klass_method.split('.', 1)
+                        candidate = (module_path, klass, method)
+                        candidates.append(candidate)
 
                 # fetch assets only on instrumented tests
-                if isinstance(test[0], str):
+                elif isinstance(test[0], str):
                     candidate = (test[1]['modulePath'],
                                  test[0],
                                  test[1]['methodName'])
@@ -289,9 +294,9 @@ class Assets(CLICmd):
     @staticmethod
     def _count_filter_args(config):
         sub_command = config.get('assets_subcommand')
-        args = [config.get("assets.{}.days".format(sub_command)),
-                config.get("assets.{}.size_filter".format(sub_command)),
-                config.get("assets.{}.overall_limit".format(sub_command))]
+        args = [config.get(f"assets.{sub_command}.days"),
+                config.get(f"assets.{sub_command}.size_filter"),
+                config.get(f"assets.{sub_command}.overall_limit")]
         return len([a for a in args if a is not None])
 
     def configure(self, parser):
@@ -479,7 +484,7 @@ class Assets(CLICmd):
         for asset in assets:
             stat = os.stat(asset)
             basename = os.path.basename(asset)
-            hash_path = "{}-CHECKSUM".format(asset)
+            hash_path = f"{asset}-CHECKSUM"
             atime = datetime.fromtimestamp(stat.st_atime)
             _, checksum = Asset.read_hash_from_file(hash_path)
             matrix.append((basename,
