@@ -18,7 +18,6 @@ Functions dedicated to find and run external commands.
 
 import contextlib
 import errno
-import fnmatch
 import glob
 import logging
 import os
@@ -36,26 +35,6 @@ from avocado.utils.wait import wait_for
 
 LOG = logging.getLogger(__name__)
 
-#: The active wrapper utility script.
-CURRENT_WRAPPER = None
-
-#: The global wrapper.
-#: If set, run every process under this wrapper.
-WRAP_PROCESS = None
-
-#: Set wrapper per program names.
-#: A list of wrappers and program names.
-#: Format: [ ('/path/to/wrapper.sh', 'progname'), ... ]
-WRAP_PROCESS_NAMES_EXPR = []
-
-#: Exception to be raised when users of this API need to know that the
-#: execution of a given process resulted in undefined behavior. One
-#: concrete example when a user, in an interactive session, let the
-#: inferior process exit before before avocado resumed the debugger
-#: session. Since the information is unknown, and the behavior is
-#: undefined, this situation will be flagged by an exception.
-UNDEFINED_BEHAVIOR_EXCEPTION = None
-
 # variable=value bash assignment
 _RE_BASH_SET_VARIABLE = re.compile(r"[a-zA-Z]\w*=.*")
 
@@ -68,8 +47,10 @@ class CmdError(Exception):
         self.additional_text = additional_text
 
     def __str__(self):
-        return ("Command '%s' failed.\nstdout: %r\nstderr: %r\nadditional_info: %s" %
-                (self.command, self.result.stdout, self.result.stderr, self.additional_text))
+        return (f"Command '{self.command}' failed.\nstdout: "
+                f"{self.result.stdout!r}\nstderr: "
+                f"{self.result.stderr!r}\nadditional_info: "
+                f"{self.additional_text}")
 
 
 class CmdInputError(Exception):
@@ -118,7 +99,7 @@ def get_capabilities(pid=None):
     """
     if pid is None:
         pid = os.getpid()
-    result = run('getpcaps %u' % pid, ignore_status=True)
+    result = run(f'getpcaps {int(pid)}', ignore_status=True)
     if result.exit_status != 0:
         return []
     if result.stderr_text.startswith('Capabilities '):
@@ -167,7 +148,7 @@ def safe_kill(pid, signal):  # pylint: disable=W0621
     :param signal: Signal number.
     """
     if get_owner_id(int(pid)) == 0:
-        kill_cmd = 'kill -%d %d' % (int(signal), int(pid))
+        kill_cmd = f'kill -{int(int(signal))} {int(int(pid))}'
         try:
             run(kill_cmd, sudo=True)
             return True
@@ -191,7 +172,7 @@ def get_parent_pid(pid):
     :returns: The parent PID
     :rtype: int
     """
-    with open('/proc/%d/stat' % pid, 'rb') as proc_stat:
+    with open(f'/proc/{int(pid)}/stat', 'rb') as proc_stat:
         parent_pid = proc_stat.read().split(b' ')[-49]
         return int(parent_pid)
 
@@ -272,8 +253,8 @@ def kill_process_tree(pid, sig=None, send_sigcont=True, timeout=0):
     elif timeout > 0:
         if not wait_for(_all_pids_dead, timeout + start - time.monotonic(),
                         step=0.01, args=(killed_pids[::-1],)):
-            raise RuntimeError("Timeout reached when waiting for pid %s "
-                               "and children to die (%s)" % (pid, timeout))
+            raise RuntimeError(f"Timeout reached when waiting for pid {pid} "
+                               f"and children to die ({timeout})")
     else:
         while not _all_pids_dead(killed_pids[::-1]):
             time.sleep(0.01)
@@ -286,7 +267,7 @@ def kill_process_by_pattern(pattern):
 
     :param pattern: normally only matched against the process name
     """
-    cmd = "pkill -f %s" % pattern
+    cmd = f"pkill -f {pattern}"
     result = run(cmd, ignore_status=True)
     if result.exit_status:
         LOG.error("Failed to run '%s': %s", cmd, result)
@@ -310,7 +291,7 @@ def process_in_ptree_is_defunct(ppid):
     except CmdError:  # Process doesn't exist
         return True
     for pid in pids:
-        cmd = "ps --no-headers -o cmd %d" % int(pid)
+        cmd = f"ps --no-headers -o cmd {int(int(pid))}"
         proc_name = system_output(cmd, ignore_status=True, verbose=False)
         if '<defunct>' in proc_name:
             defunct = True
@@ -332,7 +313,7 @@ def binary_from_shell_cmd(cmd):
     for item in cmds:
         if not _RE_BASH_SET_VARIABLE.match(item):
             return item
-    raise ValueError("Unable to parse first binary from '%s'" % cmd)
+    raise ValueError(f"Unable to parse first binary from '{cmd}'")
 
 
 #: This is kept for compatibility purposes, but is now deprecated and
@@ -381,7 +362,7 @@ class CmdResult:
         self.encoding = encoding
 
     def __str__(self):
-        return '\n'.join("%s: %r" % (key, getattr(self, key, "MISSING"))
+        return '\n'.join(f"{key}: {getattr(self, key, 'MISSING')!r}"
                          for key in ('command', 'exit_status', 'duration',
                                      'interrupted', 'pid', 'encoding',
                                      'stdout', 'stderr'))
@@ -588,7 +569,7 @@ class SubProcess:
             rc = '(running)'
         else:
             rc = self.result.exit_status
-        return '%s(cmd=%r, rc=%r)' % (self.__class__.__name__, self.cmd, rc)
+        return f'{self.__class__.__name__}(cmd={self.cmd!r}, rc={rc!r})'
 
     def __str__(self):
         if self._popen is None:
@@ -596,14 +577,14 @@ class SubProcess:
         elif self.result.exit_status is None:
             rc = '(running)'
         else:
-            rc = '(finished with exit status=%d)' % self.result.exit_status
-        return '%s %s' % (self.cmd, rc)
+            rc = f'(finished with exit status={int(self.result.exit_status)})'
+        return f'{self.cmd} {rc}'
 
     @staticmethod
     def _prepend_sudo(cmd, shell):
         if os.getuid() != 0:
             try:
-                sudo_cmd = '%s -n' % path.find_command('sudo', check_exec=False)
+                sudo_cmd = f"{path.find_command('sudo', check_exec=False)} -n"
             except path.CmdNotFoundError as details:
                 LOG.error(details)
                 LOG.error('Parameter sudo=True provided, but sudo was '
@@ -612,8 +593,8 @@ class SubProcess:
                 return cmd
             if shell:
                 if ' -s' not in sudo_cmd:
-                    sudo_cmd = '%s -s' % sudo_cmd
-            cmd = '%s %s' % (sudo_cmd, cmd)
+                    sudo_cmd = f'{sudo_cmd} -s'
+            cmd = f'{sudo_cmd} {cmd}'
         return cmd
 
     def _init_subprocess(self):
@@ -638,7 +619,7 @@ class SubProcess:
                                            shell=self.shell,
                                            env=self.env)
         except OSError as details:
-            details.strerror += " (%s)" % self.cmd
+            details.strerror += f" ({self.cmd})"
             raise details
 
         self.start_time = time.monotonic()  # pylint: disable=W0201
@@ -647,7 +628,7 @@ class SubProcess:
         self._stdout_drainer = FDDrainer(
             self._popen.stdout.fileno(),
             self.result,
-            name="%s-stdout" % self.cmd,
+            name=f"{self.cmd}-stdout",
             logger=self.logger,
             logger_prefix="[stdout] %s",
             stream_logger=None,
@@ -656,7 +637,7 @@ class SubProcess:
         self._stderr_drainer = FDDrainer(
             self._popen.stderr.fileno(),
             self.result,
-            name="%s-stderr" % self.cmd,
+            name=f"{self.cmd}-stderr",
             logger=self.logger,
             logger_prefix="[stderr] %s",
             stream_logger=None,
@@ -759,7 +740,7 @@ class SubProcess:
             pids = get_children_pids(self.get_pid())
             pids.append(self.get_pid())
             for pid in pids:
-                kill_cmd = 'kill -%d %d' % (int(sig), pid)
+                kill_cmd = f'kill -{int(int(sig))} {int(pid)}'
                 with contextlib.suppress(Exception):
                     run(kill_cmd, sudo=True)
         else:
@@ -789,8 +770,8 @@ class SubProcess:
                     the specified timeout.
         """
         def nuke_myself():
-            self.result.interrupted = ("timeout after %.9fs"
-                                       % (time.monotonic() - self.start_time))
+            timeout = time.monotonic() - self.start_time
+            self.result.interrupted = f"timeout after {timeout:.9f}s"
             try:
                 kill_process_tree(self.get_pid(), sig, timeout=1)
             except RuntimeError:
@@ -831,7 +812,7 @@ class SubProcess:
 
         if rc is None:
             # If all this work fails, we're dealing with a zombie process.
-            raise AssertionError('Zombie Process %s' % self._popen.pid)
+            raise AssertionError(f'Zombie Process {self._popen.pid}')
         self._fill_results(rc)
         return rc
 
@@ -900,64 +881,6 @@ class SubProcess:
         return self.result
 
 
-class WrapSubProcess(SubProcess):
-
-    """
-    Wrap subprocess inside an utility program.
-    """
-
-    def __init__(self, cmd, verbose=True,
-                 shell=False, env=None, wrapper=None, sudo=False,
-                 ignore_bg_processes=False, encoding=None, logger=None):
-        if wrapper is None and CURRENT_WRAPPER is not None:
-            wrapper = CURRENT_WRAPPER
-        self.wrapper = wrapper
-        if self.wrapper:
-            if not os.path.exists(self.wrapper):
-                raise IOError("No such wrapper: '%s'" % self.wrapper)
-            cmd = wrapper + ' ' + cmd
-        super().__init__(cmd, verbose, shell, env, sudo,
-                         ignore_bg_processes, encoding, logger)
-
-
-def should_run_inside_wrapper(cmd):
-    """
-    Whether the given command should be run inside the wrapper utility.
-
-    :param cmd: the command arguments, from where we extract the binary name
-    """
-    global CURRENT_WRAPPER  # pylint: disable=W0603
-    CURRENT_WRAPPER = None
-    args = shlex.split(cmd)
-    cmd_binary_name = args[0]
-
-    for script, cmd_expr in WRAP_PROCESS_NAMES_EXPR:
-        if fnmatch.fnmatch(cmd_binary_name, cmd_expr):
-            CURRENT_WRAPPER = script
-
-    if WRAP_PROCESS is not None and CURRENT_WRAPPER is None:
-        CURRENT_WRAPPER = WRAP_PROCESS
-
-    if CURRENT_WRAPPER is None:
-        return False
-    else:
-        return True
-
-
-def get_sub_process_klass(cmd):
-    """
-    Which sub process implementation should be used
-
-    Either the regular one, or the GNU Debugger version
-
-    :param cmd: the command arguments, from where we extract the binary name
-    """
-    if should_run_inside_wrapper(cmd):
-        return WrapSubProcess
-    else:
-        return SubProcess
-
-
 def run(cmd, timeout=None, verbose=True, ignore_status=False,
         shell=False, env=None, sudo=False, ignore_bg_processes=False,
         encoding=None, logger=None):
@@ -1002,11 +925,10 @@ def run(cmd, timeout=None, verbose=True, ignore_status=False,
         raise CmdInputError("Invalid empty command")
     if encoding is None:
         encoding = astring.ENCODING
-    klass = get_sub_process_klass(cmd)
-    sp = klass(cmd=cmd, verbose=verbose,
-               shell=shell, env=env,
-               sudo=sudo, ignore_bg_processes=ignore_bg_processes,
-               encoding=encoding, logger=logger)
+    sp = SubProcess(cmd=cmd, verbose=verbose,
+                    shell=shell, env=env,
+                    sudo=sudo, ignore_bg_processes=ignore_bg_processes,
+                    encoding=encoding, logger=logger)
     cmd_result = sp.run(timeout=timeout)
     fail_condition = cmd_result.exit_status != 0 or cmd_result.interrupted
     if fail_condition and not ignore_status:
@@ -1221,7 +1143,7 @@ def get_owner_id(pid):
     :return: user id of the process owner
     """
     try:
-        return os.stat('/proc/%d/' % pid).st_uid
+        return os.stat(f'/proc/{int(pid)}/').st_uid
     except OSError:
         return None
 
