@@ -1,8 +1,9 @@
-from avocado.core import nrunner
-from avocado.core.runners.utils.messages import FinishedMessage, StartedMessage
+from avocado.core.nrunner.app import BaseRunnerApp
+from avocado.core.nrunner.runner import BaseRunner
+from avocado.core.utils.messages import FinishedMessage, StartedMessage
 
 
-class MagicRunner(nrunner.BaseRunner):
+class MagicRunner(BaseRunner):
     """Runner for magic words
 
     When creating the Runnable, use the following attributes:
@@ -21,23 +22,24 @@ class MagicRunner(nrunner.BaseRunner):
                            uri='pass')
     """
 
-    def run(self):
+    def run(self, runnable):
         yield StartedMessage.get()
-        if self.runnable.uri in ['pass', 'fail']:
-            result = self.runnable.uri
+        if runnable.uri in ['pass', 'fail']:
+            result = runnable.uri
         else:
             result = 'error'
         yield FinishedMessage.get(result)
 
 
-class RunnerApp(nrunner.BaseRunnerApp):
+class RunnerApp(BaseRunnerApp):
     PROG_NAME = 'avocado-runner-magic'
     PROG_DESCRIPTION = 'nrunner application for magic tests'
-    RUNNABLE_KINDS_CAPABLE = {'magic': MagicRunner}
+    RUNNABLE_KINDS_CAPABLE = ['magic']
 
 
 def main():
-    nrunner.main(RunnerApp)
+    app = RunnerApp(print)
+    app.run()
 
 
 if __name__ == '__main__':
