@@ -1,6 +1,6 @@
 from avocado import Test
 from avocado.utils.process import run
-from avocado.utils.software_manager import SoftwareManager
+from avocado.utils.software_manager.manager import SoftwareManager
 
 
 class CancelTest(Test):
