@@ -8,17 +8,11 @@ from selftests.utils import AVOCADO, BASEDIR, TestCaseTmpDir
 
 SCRIPT_CONTENT = (f"""#!/bin/sh
 echo "Avocado Version: $AVOCADO_VERSION"
-echo "Avocado Test basedir: $AVOCADO_TEST_BASEDIR"
 echo "Avocado Test workdir: $AVOCADO_TEST_WORKDIR"
-echo "Avocado Test logdir: $AVOCADO_TEST_LOGDIR"
-echo "Avocado Test logfile: $AVOCADO_TEST_LOGFILE"
 echo "Avocado Test outputdir: $AVOCADO_TEST_OUTPUTDIR"
 
 test "$AVOCADO_VERSION" = "{VERSION}" -a \
-     -d "$AVOCADO_TEST_BASEDIR" -a \
      -d "$AVOCADO_TEST_WORKDIR" -a \
-     -d "$AVOCADO_TEST_LOGDIR" -a \
-     -f "$AVOCADO_TEST_LOGFILE" -a \
      -d "$AVOCADO_TEST_OUTPUTDIR"
 """)
 
@@ -36,7 +30,7 @@ class EnvironmentVariablesTest(TestCaseTmpDir):
     def test_environment_vars(self):
         os.chdir(BASEDIR)
         cmd_line = (f'{AVOCADO} run --job-results-dir {self.tmpdir.name} '
-                    f'{self.script.path} --test-runner=runner')
+                    f'{self.script.path}')
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
         self.assertEqual(result.exit_status, expected_rc,
