@@ -81,15 +81,7 @@ def hello():
     print('Hello World!')
 """
 
-PY_SIMPLE_TEST = """#!/usr/bin/env python
-def hello():
-    print('Hello World!')
-
-if __name__ == "__main__":
-    hello()
-"""
-
-SIMPLE_TEST = """#!/bin/sh
+EXEC_TEST = """#!/bin/sh
 true
 """
 
@@ -165,7 +157,7 @@ class ListTestFunctional(TestCaseTmpDir):
         self.assertEqual(test_process.returncode, exit_codes.AVOCADO_TESTS_FAIL)
 
     def test_simple(self):
-        self._test('simpletest.sh', SIMPLE_TEST, 'exec-test', self.MODE_0775)
+        self._test('simpletest.sh', EXEC_TEST, 'exec-test', self.MODE_0775)
 
     def test_pass(self):
         self._test('passtest.py', AVOCADO_TEST_OK, 'avocado-instrumented')
