@@ -1,7 +1,7 @@
 import os
 import unittest.mock
 
-from avocado.core.requirements import cache
+from avocado.core.dependencies.requirements import cache
 from selftests.utils import TestCaseTmpDir
 
 ENTRIES = [
@@ -24,7 +24,7 @@ class Cache(TestCaseTmpDir):
 
     def test_entries(self):
         with unittest.mock.patch(
-                'avocado.core.requirements.cache.backends.sqlite.CACHE_DATABASE_PATH',
+                'avocado.core.dependencies.requirements.cache.backends.sqlite.CACHE_DATABASE_PATH',
                 os.path.join(self.tmpdir.name,
                              'requirements.sqlite')):
             for entry in ENTRIES:
@@ -33,7 +33,7 @@ class Cache(TestCaseTmpDir):
 
     def test_empty(self):
         with unittest.mock.patch(
-                'avocado.core.requirements.cache.backends.sqlite.CACHE_DATABASE_PATH',
+                'avocado.core.dependencies.requirements.cache.backends.sqlite.CACHE_DATABASE_PATH',
                 os.path.join(self.tmpdir.name,
                              'requirements.sqlite')):
             self.assertFalse(cache.get_requirement(*ENTRIES[0]))
