@@ -7,7 +7,7 @@ from avocado.utils import process, script
 # is also the same
 from selftests.functional.test_list import \
     AVOCADO_TEST_OK as AVOCADO_INSTRUMENTED_TEST
-from selftests.functional.test_list import SIMPLE_TEST as EXEC_TEST
+from selftests.functional.test_list import EXEC_TEST
 from selftests.utils import AVOCADO, BASEDIR
 
 
