@@ -1,7 +1,7 @@
 import os
 import unittest
 
-from avocado.utils import software_manager
+from avocado.utils.software_manager import manager
 from selftests.utils import BASEDIR, TestCaseTmpDir, skipUnlessPathExists
 
 
@@ -16,21 +16,21 @@ class SoftwareManager(TestCaseTmpDir):
         self.deb_path = os.path.join(assets_dir, "hello.deb")
 
     def test_extract_from_rpm(self):
-        manager = software_manager.SoftwareManager()
-        result = manager.extract_from_package(self.rpm_path,
-                                              self.tmpdir.name)
+        mn = manager.SoftwareManager()
+        result = mn.extract_from_package(self.rpm_path,
+                                         self.tmpdir.name)
         self.assertEqual(self.tmpdir.name, result)
 
     def test_extract_from_deb(self):
-        manager = software_manager.SoftwareManager()
-        result = manager.extract_from_package(self.deb_path,
-                                              self.tmpdir.name)
+        mn = manager.SoftwareManager()
+        result = mn.extract_from_package(self.deb_path,
+                                         self.tmpdir.name)
         self.assertEqual(self.tmpdir.name, result)
 
     def test_extract_permission(self):
-        manager = software_manager.SoftwareManager()
+        mn = manager.SoftwareManager()
         with self.assertRaises(NotImplementedError) as context:
-            manager.extract_from_package('/dev/null', self.tmpdir.name)
+            mn.extract_from_package('/dev/null', self.tmpdir.name)
         expected = 'No package manager supported was found for package '
         self.assertIn(expected, str(context.exception))
 
