@@ -1,7 +1,8 @@
 import os
 import unittest
 
-from avocado.utils import distro, software_manager
+from avocado.utils import distro
+from avocado.utils.software_manager import backends, manager
 from selftests.utils import BASEDIR, setup_avocado_loggers
 
 setup_avocado_loggers()
@@ -17,22 +18,22 @@ def apt_supported_distro():
 class Apt(unittest.TestCase):
 
     def test_provides(self):
-        sm = software_manager.SoftwareManager()
+        sm = manager.SoftwareManager()
         self.assertEqual(sm.provides('/bin/login'), 'login')
         self.assertTrue(isinstance(sm.backend,
-                                   software_manager.backends.apt.AptBackend))
+                                   backends.apt.AptBackend))
 
 
 class Dpkg(unittest.TestCase):
 
     def test_is_valid(self):
         deb_path = os.path.join(BASEDIR, 'selftests', '.data', 'hello.deb')
-        dpkg = software_manager.backends.dpkg.DpkgBackend
+        dpkg = backends.dpkg.DpkgBackend
         self.assertTrue(dpkg.is_valid(deb_path))
 
     def test_is_not_valid(self):
         not_deb_path = os.path.join(BASEDIR, 'selftests', '.data', 'guaca.a')
-        dpkg = software_manager.backends.dpkg.DpkgBackend
+        dpkg = backends.dpkg.DpkgBackend
         self.assertFalse(dpkg.is_valid(not_deb_path))
 
 
